package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import models.Almacenamiento;
import persistance.services.ABMService;

@Path("/Almacenamiento")
public class AlmacenamientoResource {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<Almacenamiento> almaDAO = new ABMService<Almacenamiento>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getAlmacenamientos() {
        try {
            List<Almacenamiento> almas = almaDAO.getAll(Almacenamiento.class);
            return Response.ok(almas).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban los almacenamiento.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getAlmacenamientoById(@PathParam("id") Long id) {
        try {
            Optional<Almacenamiento> alma = almaDAO.get(Almacenamiento.class, id);
            if (alma.isPresent()) {
                return Response.ok(alma.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Almacenamiento no encontrado con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba el almacenamiento.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearAlmacenamiento(Almacenamiento alma) {
        try {
            Response.Status status = almaDAO.save(alma);
            return Response.status(status).entity(alma).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba el almacenamiento.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarAlmacenamiento(Almacenamiento alma) {
        try {
            Response.Status status = almaDAO.update(alma);
            return Response.status(status).entity(alma).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba el almacenamiento.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarAlmacenamiento(Almacenamiento alma) {
		try {
	        Response.Status status = almaDAO.delete(alma);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba el almacenamiento.").build();
	    }
	}
	
}
