package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import models.Bien;
import persistance.services.ABMService;

@Path("/Bien")
public class BienResource {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<Bien> bienDAO = new ABMService<Bien>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getBienes() {
        try {
            List<Bien> canales = bienDAO.getAll(Bien.class);
            return Response.ok(canales).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban los bienes.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getBienById(@PathParam("id") Long id) {
        try {
            Optional<Bien> canal = bienDAO.get(Bien.class, id);
            if (canal.isPresent()) {
                return Response.ok(canal.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Bien no encontrado con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba el Bien.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearBien(Bien bien) {
        try {
            Response.Status status = bienDAO.save(bien);
            return Response.status(status).entity(bien).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba el Bien.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarBien(Bien bien) {
        try {
            Response.Status status = bienDAO.update(bien);
            return Response.status(status).entity(bien).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba el Bien.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarBien(Bien bien) {
		try {
	        Response.Status status = bienDAO.delete(bien);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba el Bien.").build();
	    }
	}
	
}
