package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;
import javax.ws.rs.core.MediaType;

import models.Canal;
import persistance.services.ABMService;

@Path("/canal")
public class CanalResource {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<Canal> canalDAO = new ABMService<Canal>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getCanales() {
        try {
            List<Canal> canales = canalDAO.getAll(Canal.class);
            return Response.ok(canales).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban Canales.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getCanalById(@PathParam("id") Long id) {
        try {
            Optional<Canal> canal = canalDAO.get(Canal.class, id);
            if (canal.isPresent()) {
                return Response.ok(canal.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Canal no encontrado con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba el Canal.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearCanal(Canal canal) {
        try {
            Response.Status status = canalDAO.save(canal);
            return Response.status(status).entity(canal).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba el Canal.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarCanal(Canal canal) {
        try {
            Response.Status status = canalDAO.update(canal);
            return Response.status(status).entity(canal).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba el Canal.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarCanal(Canal canal) {
		try {
	        Response.Status status = canalDAO.delete(canal);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba el Canal.").build();
	    }
	}
	
}
