package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import models.FamiliaProductora;
import persistance.services.ABMService;

@Path("/FamiliaProductora")
public class FamiliaProductoraResource {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<FamiliaProductora> FamProDAO = new ABMService<FamiliaProductora>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getFamiliasProductoras() {
        try {
            List<FamiliaProductora> fams = FamProDAO.getAll(FamiliaProductora.class);
            return Response.ok(fams).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban las familias productoras.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getFamiliaProductoraById(@PathParam("id") Long id) {
        try {
            Optional<FamiliaProductora> fampro = FamProDAO.get(FamiliaProductora.class, id);
            if (fampro.isPresent()) {
                return Response.ok(fampro.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Familia productora no encontrado con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba la familia productora.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearFamiliaProductora(FamiliaProductora fam) {
        try {
            Response.Status status = FamProDAO.save(fam);
            return Response.status(status).entity(fam).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba la familia productora.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarFamiliaProductora(FamiliaProductora fam) {
        try {
            Response.Status status = FamProDAO.update(fam);
            return Response.status(status).entity(fam).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba la familia productora.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarFamiliaProductora(FamiliaProductora fam) {
		try {
	        Response.Status status = FamProDAO.delete(fam);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba la familia productora").build();
	    }
	}
	
}
