package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import models.Nota;
import persistance.services.ABMService;

@Path("/Nota")
public class NotaResources {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<Nota> notaDAO = new ABMService<Nota>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getNotas() {
        try {
            List<Nota> notas = notaDAO.getAll(Nota.class);
            return Response.ok(notas).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban las notas.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getNotaById(@PathParam("id") Long id) {
        try {
            Optional<Nota> nota = notaDAO.get(Nota.class, id);
            if (nota.isPresent()) {
                return Response.ok(nota.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Nota no encontrada con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba la nota.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearNota(Nota nota) {
        try {
            Response.Status status = notaDAO.save(nota);
            return Response.status(status).entity(nota).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba la nota.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarNota(Nota nota) {
        try {
            Response.Status status = notaDAO.update(nota);
            return Response.status(status).entity(nota).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba la nota.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarNota(Nota nota) {
		try {
	        Response.Status status = notaDAO.delete(nota);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba la nota.").build();
	    }
	}
	
}
