package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import models.Orden;
import persistance.services.ABMService;

@Path("/Orden")
public class OrdenResource {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<Orden> ordenDAO = new ABMService<Orden>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getOrdenes() {
        try {
            List<Orden> ordenes = ordenDAO.getAll(Orden.class);
            return Response.ok(ordenes).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban las ordenes.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getOrdenById(@PathParam("id") Long id) {
        try {
            Optional<Orden> orden = ordenDAO.get(Orden.class, id);
            if (orden.isPresent()) {
                return Response.ok(orden.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Orden no encontrada con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba la orden.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearOrden(Orden orden) {
        try {
            Response.Status status = ordenDAO.save(orden);
            return Response.status(status).entity(orden).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba la orden.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarOrden(Orden orden) {
        try {
            Response.Status status = ordenDAO.update(orden);
            return Response.status(status).entity(orden).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba la orden.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarOrden(Orden orden) {
		try {
	        Response.Status status = ordenDAO.delete(orden);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba la orden.").build();
	    }
	}
	
}
