package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import models.Receta;
import persistance.services.ABMService;

@Path("/Receta")
public class RecetaResource {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<Receta> recDAO = new ABMService<Receta>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getRecetas() {
        try {
            List<Receta> recetas = recDAO.getAll(Receta.class);
            return Response.ok(recetas).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban las recetas.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getRecetaById(@PathParam("id") Long id) {
        try {
            Optional<Receta> receta = recDAO.get(Receta.class, id);
            if (receta.isPresent()) {
                return Response.ok(receta.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Receta no encontrada con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba la receta.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearReceta(Receta receta) {
        try {
            Response.Status status = recDAO.save(receta);
            return Response.status(status).entity(receta).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba la receta.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarReceta(Receta receta) {
        try {
            Response.Status status = recDAO.update(receta);
            return Response.status(status).entity(receta).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba la receta.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarReceta(Receta receta) {
		try {
	        Response.Status status = recDAO.delete(receta);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba la receta.").build();
	    }
	}

}
