package resourcesRest;

import java.util.List;
import java.util.Optional;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import models.Usuario;
import persistance.services.ABMService;

@Path("/usuario")
public class UsuarioResource {
	@Context
	UriInfo uriInfo;
	
	@Context
	Request request;
	
	private ABMService<Usuario> usuarioDAO = new ABMService<Usuario>();
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
    public Response getUsuarios() {
        try {
            List<Usuario> usuarios = usuarioDAO.getAll(Usuario.class);
            return Response.ok(usuarios).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaban Usuarios.").build();
        }
    }

	@GET
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
    public Response getUsuarioById(@PathParam("id") Long id) {
        try {
            Optional<Usuario> usuario = usuarioDAO.get(Usuario.class, id);
            if (usuario.isPresent()) {
                return Response.ok(usuario.get()).build();
            } else {
                return Response.status(Response.Status.NOT_FOUND).entity("Usuario no encontrado con ID: " + id).build();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se buscaba el Usuario.").build();
        }
    }
	
	@POST
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
    public Response crearUsuario(Usuario usuario) {
        try {
            Response.Status status = usuarioDAO.save(usuario);
            return Response.status(status).entity(usuario).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se creaba el Usuario.").build();
        }
    }
	
	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response editarUsuario(Usuario usuario) {
        try {
            Response.Status status = usuarioDAO.update(usuario);
            return Response.status(status).entity(usuario).build();
        } catch (Exception e) {
            e.printStackTrace();
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se actualizaba el Usuario.").build();
        }
    }
	
	@DELETE
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response borrarUsuario(Usuario usuario) {
		try {
	        Response.Status status = usuarioDAO.delete(usuario);
	        return Response.status(status).build();
	    } catch (Exception e) {
	        e.printStackTrace();
	        return Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Un error surgio mientras se eliminaba el Usuario.").build();
	    }
	}
	

}
